@@ -826,6 +826,11 @@ blog_lj_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 		
 		for (j = 0; j < prop_count; j++)
 		{
+			g_snprintf (key, 32, "prop_%d_itemid", j + 1);
+			mesg = drivel_request_value_lookup (dr, key);
+			if (strcmp (mesg, itemid[i]))
+				continue;
+
 			g_snprintf (key, 32, "prop_%d_name", j + 1);
 			mesg = drivel_request_value_lookup (dr, key);
 
@@ -869,28 +874,28 @@ blog_lj_parse_getevents_request (DrivelClient *dc, DrivelRequest *dr)
 			{
 				prop = journal_prop_new ();
 				prop->name = g_strdup ("music");
-				prop->value = g_strdup (picture[i]);
+				prop->value = g_strdup (music[i]);
 				g_array_append_val (entry->properties, prop);
 			}
 			if (mood[i])
 			{
 				prop = journal_prop_new ();
 				prop->name = g_strdup ("mood");
-				prop->value = g_strdup (picture[i]);
+				prop->value = g_strdup (mood[i]);
 				g_array_append_val (entry->properties, prop);
 			}
 			if (comments[i])
 			{
 				prop = journal_prop_new ();
 				prop->name = g_strdup ("comments");
-				prop->value = g_strdup (picture[i]);
+				prop->value = g_strdup (comments[i]);
 				g_array_append_val (entry->properties, prop);
 			}
 			if (autoformat[i])
 			{
 				prop = journal_prop_new ();
 				prop->name = g_strdup ("autoformat");
-				prop->value = g_strdup (picture[i]);
+				prop->value = g_strdup (autoformat[i]);
 				g_array_append_val (entry->properties, prop);
 			}
 			prop = journal_prop_new ();
