@@ -50,7 +50,8 @@ blog_lj_build_postevent_request (const gchar *username, const gchar *uri,
 		const gchar *event, const gchar *music, const gchar *mood,
 		gint moodid, const gchar *subject, const gchar *security, gint mask,
 		const gchar *picture, gint year, gint month, gint day, gint hour,
-		gint minute, gint nocomments, gint preformatted, const DrivelJournal *dj);
+		gint minute, gint nocomments, gint preformatted, 
+		const DrivelJournal *dj, gint backdate);
 		
 DrivelRequest*
 blog_lj_build_editevent_request (const gchar *username, const gchar *uri, 
