@@ -752,12 +752,15 @@ friends_list_changed (GtkTreeSelection *selection, gpointer data)
 		GdkColor gdk_colour;
 		gchar hex[5];
 
+		friend_text = NULL;
 		hex[0] = '0';
 		hex[1] = 'X';
 		hex[4] = '\0';
 
 		gtk_tree_model_get (model, &iter, FRIEND_COL, &friend, -1);
-		
+
+		/* These should only be available if we have this user listed
+		   as a friend. */
 		gtk_widget_set_sensitive (dc->friend_remove, friend);
 		gtk_widget_set_sensitive (dc->friends_fg_colour, friend);
 		gtk_widget_set_sensitive (dc->friends_bg_colour, friend);
@@ -770,6 +773,13 @@ friends_list_changed (GtkTreeSelection *selection, gpointer data)
 				TYPE_INT_COL, &type_int,
 				-1);
 
+		/* This should be sensitive if a username is available */
+		if (friend_text)
+		  gtk_widget_set_sensitive (dc->friend_view_journal, TRUE);
+		else
+		  gtk_widget_set_sensitive (dc->friend_view_journal, FALSE);
+
+
 		if (type_int == FRIEND_TYPE_COMMUNITY)
 			type = g_strdup (_("Community"));
 		else if (type_int == FRIEND_TYPE_FEED)
@@ -962,6 +972,29 @@ friends_list_remove_cb (GtkWidget *widget, gpointer data)
 	return;
 }
 
+static void
+friends_list_view_journal_cb (GtkWidget *widget, gpointer data)
+{
+	gchar *friend;
+	gchar url[255];
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	DrivelClient *dc = (DrivelClient *) data;
+	
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dc->friend_list));
+	gtk_tree_selection_get_selected (selection, &model, &iter);
+	gtk_tree_model_get (model, &iter, USERNAME_COL, &friend, -1);
+
+	/* XXX */
+	g_snprintf (url, 255, "%s/users/%s", dc->user->server, friend);
+	gnome_url_show (url, NULL);
+
+	g_free (friend);
+
+	return;
+}
+
 static void
 set_link_text_cb (GtkWidget *entry, gpointer data)
 {
@@ -1515,6 +1548,12 @@ display_edit_friends_dialog (DrivelClient *dc)
 			G_CALLBACK (friends_list_remove_cb), dc);
 	dc->friend_remove = button;
 	
+	button = glade_xml_get_widget (xml, "friends_view_journal_button");
+	gtk_widget_set_sensitive (button, FALSE);
+	g_signal_connect (G_OBJECT (button), "clicked",
+			G_CALLBACK (friends_list_view_journal_cb), dc);
+	dc->friend_view_journal = button;
+
 	g_signal_connect (G_OBJECT (dialog), "destroy",
 			G_CALLBACK (gtk_widget_destroyed), &dialog);
 	g_signal_connect (G_OBJECT (dialog), "response",
@@ -1782,16 +1821,16 @@ display_edit_preferences_dialog (DrivelClient *dc)
 	static GtkWidget *dialog = NULL;
 	GtkWidget *widget, *spellcheck;
 	GtkListStore *picture_store;
-	GtkTreeIter iter;
 	GtkCellRenderer *renderer;
 	gboolean state;
 	gchar *string;
 	gint num;
 #ifdef HAVE_GTKSPELL
 	gint sel = -1;
+	GtkTreeIter iter;
 	GtkListStore *language_store;
-#endif /* HAVE_GTKSPELL */
 	GSList *list;
+#endif /* HAVE_GTKSPELL */
 	GConfValue *value;
 
 	if (dialog)
@@ -1865,6 +1904,8 @@ display_edit_preferences_dialog (DrivelClient *dc)
 	dc->pref_dictionary_box = widget;
 	widget = glade_xml_get_widget (xml, "prefs_general_entry_dictionary");
 	dc->pref_dictionary = widget;
+	widget = glade_xml_get_widget (xml, "prefs_general_entry_dictionary_label");
+	gtk_label_set_mnemonic_widget(GTK_LABEL(widget),dc->pref_dictionary);
 
 #ifdef HAVE_GTKSPELL
 	
@@ -1932,7 +1973,7 @@ display_edit_preferences_dialog (DrivelClient *dc)
 			  G_CALLBACK (nullify_pointer), &(dc->pref_dictionary));
 	
 	/* picture */
-	picture_store = gtk_list_store_new (2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
+	picture_store = gtk_list_store_new (2, G_TYPE_STRING, GDK_TYPE_PIXBUF);
 	fill_picture_menu (dc, picture_store);
 	widget = glade_xml_get_widget (xml, "pref_defaults_picture");
 	gtk_combo_box_set_model (GTK_COMBO_BOX (widget), GTK_TREE_MODEL (picture_store));
