@@ -25,12 +25,10 @@
  * 
  * This is the spinner (for busy feedback) for the location bar
  *
- * $Id: ephy-spinner.c,v 1.1 2004/08/04 22:49:44 todd Exp $
+ * $Id: ephy-spinner.c,v 1.2 2005/01/11 00:21:18 todd Exp $
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <config.h>
 
 #include "ephy-spinner.h"
 
