@@ -19,11 +19,11 @@
  * 		Davyd Madeley <davyd@ucc.asn.au>
  */
 
+#include <config.h>
+
 #include <gnome.h>
 #include <glade/glade.h>
 
-#include <config.h>
-
 #include "drivel.h"
 #include "insert_poll_dialog.h"
 #include "journal.h"
@@ -127,7 +127,6 @@ void
 display_insert_poll_dialog (DrivelClient *dc)
 {
 	GladeXML *xml;
-	GtkWidget *parent;
 	DrivelPoll *dp;
 	GtkListStore *voters_store, *results_store, *type_store;
 	GtkTreeIter iter;
@@ -136,14 +135,13 @@ display_insert_poll_dialog (DrivelClient *dc)
 	dp = g_new0 (DrivelPoll, 1);
 	dp->dc = dc;
 	
-	xml = load_glade_xml ();
+	xml = load_glade_xml ("poll_dialog");
 	if (!xml)
 		return;
 
 	/* dialog */
 	dp->dialog = glade_xml_get_widget (xml, "poll_dialog");
-	parent = drivel_get_current_window (dc->window_list);
-	gtk_window_set_transient_for (GTK_WINDOW (dp->dialog), GTK_WINDOW (parent));
+	gtk_window_set_transient_for (GTK_WINDOW (dp->dialog), GTK_WINDOW (dc->current_window));
 	drivel_push_current_window (dc, dp->dialog);
 	/* the name of the poll */
 	dp->poll_name = glade_xml_get_widget (xml, "poll_name");
@@ -652,6 +650,7 @@ selection_changed_cb (GtkTreeSelection *tree_selection, gpointer user_data)
 			case POLL_TYPE_RADIO:
 			case POLL_TYPE_CHECK:
 				gtk_entry_set_text (GTK_ENTRY (dp->options_main_question), text);
+				gtk_combo_box_set_active (GTK_COMBO_BOX (dp->options_main_type), type);
 				break;
 			case POLL_TYPE_ANSWER:
 				gtk_entry_set_text (GTK_ENTRY (dp->options_answer_text), text);
@@ -666,6 +665,7 @@ selection_changed_cb (GtkTreeSelection *tree_selection, gpointer user_data)
 					gtk_entry_set_text (GTK_ENTRY (dp->options_textentry_maxlength), g_strdup_printf ("%i", value2));
 				else
 					gtk_entry_set_text (GTK_ENTRY (dp->options_textentry_maxlength), g_strdup(""));
+				gtk_combo_box_set_active (GTK_COMBO_BOX (dp->options_main_type), type);
 				break;
 			case POLL_TYPE_SCALE:
 				gtk_entry_set_text (GTK_ENTRY (dp->options_main_question), text);
@@ -678,9 +678,9 @@ selection_changed_cb (GtkTreeSelection *tree_selection, gpointer user_data)
 				gtk_spin_button_set_value (GTK_SPIN_BUTTON (dp->options_scale_from), value1);
 				gtk_spin_button_set_value (GTK_SPIN_BUTTON (dp->options_scale_to), value2);
 				gtk_spin_button_set_value (GTK_SPIN_BUTTON (dp->options_scale_by), value3);
+				gtk_combo_box_set_active (GTK_COMBO_BOX (dp->options_main_type), type);
 				break;
 		}
-		gtk_combo_box_set_active (GTK_COMBO_BOX (dp->options_main_type), type);
 	}
 	else
 	{
