@@ -23,7 +23,7 @@
 #define _JOURNAL_H_
 
 #include "drivel.h"
-
+     
 void
 journal_window_build (DrivelClient *dc);
 
@@ -31,9 +31,11 @@ void
 jounal_edit_preferences (DrivelClient *dc);
 
 void
-journal_edit_entry (DrivelClient *dc, const gchar *itemid, const gchar *event, const gchar *security,
-		const gchar *allowmask, const gchar *subject, const gchar *mood, const gchar *music, const gchar *picture,
-		const gchar *eventtime, const gchar *comments, const gchar *autoformat);
+journal_edit_entry (DrivelClient *dc, const gchar *itemid, const gchar *event, 
+		const gchar *security, const gchar *allowmask, const gchar *subject, 
+		const gchar *mood, const gchar *music, const gchar *picture,
+		const gchar *eventtime, const gchar *comments, const gchar *autoformat, 
+		const gchar *link);
 
 void
 journal_edit_entry_finished (DrivelClient *dc);
@@ -68,4 +70,24 @@ journal_window_state_save (DrivelClient *dc);
 void
 journal_window_state_restore (DrivelClient *dc);
 
+/* Clears up the entry window following a successful post */
+void
+journal_finished_post (DrivelClient *dc);
+
+DrivelJournalProp*
+journal_prop_new (void);
+
+void
+journal_prop_free (DrivelJournalProp *prop);
+
+DrivelJournalEntry*
+journal_entry_new (void);
+
+void
+journal_entry_free (DrivelJournalEntry *entry);
+
+/* Refresh the Recent Entries menu */
+void
+journal_refresh_recent_entries (DrivelClient *dc);
+
 #endif
