@@ -33,6 +33,12 @@ void
 login_window_build (DrivelClient *dc);
 
 void
-set_user_login_prefs (DrivelClient *dc, const gchar *username);
+set_user_login_prefs (DrivelClient *dc);
+
+DrivelUser*
+get_drivel_user (DrivelClient *dc);
+
+void
+user_list_changed (DrivelClient *dc);
 
 #endif
