@@ -245,7 +245,7 @@ validate_username (const gchar *username)
 	{
 		c = g_utf8_get_char_validated (p, -1);
 
-		if (!g_unichar_isalnum (c) && c != '_' && c!= '-')
+		if (!g_unichar_isalnum (c) && c != '_' && c!= '-' && c!='@' && c!='.')
 		{
 			retval = FALSE;
 			break;
@@ -417,7 +417,7 @@ fill_picture_menu (DrivelClient *dc, GtkListStore *picture_store)
 		} else
 			pixbuf_small = NULL;
 		gtk_list_store_append (picture_store, &iter);
-		gtk_list_store_set (picture_store, &iter, 0, pixbuf_small, 1, text, -1);
+		gtk_list_store_set (picture_store, &iter, 1, pixbuf_small, 0, text, -1);
 		
 		g_free (pickw);
 	}
@@ -914,10 +914,12 @@ main (gint argc, gchar **argv)
 		{ "verbose", 'v', POPT_ARG_NONE, &verbose, 0, "Display debugging output", "" },
 		{ NULL }
 	};
-	
+
+#ifdef ENABLE_NLS	
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 	xmlInitParser ();
 	
 	error = NULL;
