@@ -35,4 +35,8 @@ net_enqueue_request (DrivelClient *dc, DrivelRequest *dr);
 gint
 net_start_thread (DrivelClient *dc);
 
+/* send a ping to technorati */
+void
+net_ping_technorati (DrivelClient *dc);
+
 #endif /* _NETWORK_H_ */
