@@ -19,6 +19,8 @@
  * 		Todd Kulesza <todd@dropline.net>
  */
 
+#include <config.h>
+
 #include <gnome.h>
 #include <curl/curl.h>
 
@@ -30,12 +32,13 @@
 #include "tray.h"
 #include "drivel.h"
 
-#define CHECKFRIENDS_INTERVAL	30
+#define CHECKFRIENDS_INTERVAL	30 /* in seconds */
 
 EggTrayIcon *tray_icon = NULL;
-GtkWidget *icon = NULL;
 GtkWidget *menu = NULL;
-GtkWidget *show_entry = NULL;
+guint checkid = 0;
+
+/* This is called by a timer to check a user's LiveJournal Friends Page */
 
 static gboolean
 checkfriends (gpointer data)
@@ -51,7 +54,8 @@ checkfriends (gpointer data)
 	{
 		DrivelRequest *dr;
 		
-		dr = blog_lj_build_checkfriends_request (dc->username, dc->lastupdate);
+		dr = blog_lj_build_checkfriends_request (dc->user->username, 
+				dc->user->server, dc->lastupdate);
 		net_enqueue_request (dc, dr);
 	}
 	else
@@ -63,19 +67,7 @@ checkfriends (gpointer data)
 	return TRUE;
 }
 
-static void
-menu_show_cb (GtkCheckMenuItem *item, DrivelClient *dc)
-{
-	gboolean active;
-	
-	active = gtk_check_menu_item_get_active (item);
-	if (active)
-		tray_show_entry (dc);
-	else
-		tray_hide_entry (dc);
-	
-	return;
-}
+/* Update the GConf key */
 
 static void
 menu_remove_cb (GtkMenuItem *item, DrivelClient *dc)
@@ -85,25 +77,49 @@ menu_remove_cb (GtkMenuItem *item, DrivelClient *dc)
 	return;
 }
 
+/* Once the user views their Friends Page, clear the counters and hide the icon */
+
 static void
-view_friends_cb (GtkMenuItem *item, DrivelClient *dc)
+viewed_friends (DrivelClient *dc)
 {
-	gchar *url;
-	
-	url = g_strdup_printf ("http://www.livejournal.com/~%s/friends/", 
-			dc->username);
-	
-	gnome_url_show (url, NULL);
-	
 	dc->friends_update = FALSE;
 	g_free (dc->lastupdate);
 	dc->lastupdate = g_strdup ("");
 	
-	tray_icon_update (TRAY_NORMAL);
+	tray_display (FALSE);
 	
 	return;
 }
+
+/* Display the user's Friends Page in their default web browser */
+
+static void
+view_friends (DrivelClient *dc)
+{
+	gchar *url;
 	
+	url = g_strdup_printf ("http://www.livejournal.com/~%s/friends/", 
+			dc->user->username);
+	gnome_url_show (url, NULL);
+	viewed_friends (dc);
+	
+	g_free (url);
+	
+	return;
+}
+
+/* Right-click menu callback for View Friends */
+
+static void
+view_friends_cb (GtkMenuItem *item, DrivelClient *dc)
+{
+	view_friends (dc);
+	
+	return;
+}
+
+/* Build the right-click menu */
+
 static void
 create_menu (DrivelClient *dc)
 {
@@ -117,15 +133,7 @@ create_menu (DrivelClient *dc)
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	menuitem = gtk_separator_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	menuitem = gtk_check_menu_item_new_with_mnemonic (_("_Show Entry"));
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), TRUE);
-	g_signal_connect (G_OBJECT (menuitem), "toggled",
-		G_CALLBACK (menu_show_cb), dc);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	show_entry = menuitem;
-	menuitem = gtk_separator_menu_item_new ();
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	menuitem = gtk_menu_item_new_with_label (_("Remove From Tray"));
+	menuitem = gtk_menu_item_new_with_mnemonic (_("_Remove From Tray"));
 	g_signal_connect (G_OBJECT (menuitem), "activate",
 		G_CALLBACK (menu_remove_cb), dc);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
@@ -135,17 +143,7 @@ create_menu (DrivelClient *dc)
 	return;
 }
 
-static void
-viewed_friends (DrivelClient *dc)
-{
-	dc->friends_update = FALSE;
-	g_free (dc->lastupdate);
-	dc->lastupdate = g_strdup ("");
-	
-	tray_icon_update (TRAY_NORMAL);
-	
-	return;
-}
+/* Handle button-press events */
 
 static void
 clicked (GtkWidget *widget, GdkEventButton *event, gpointer data)
@@ -158,20 +156,14 @@ clicked (GtkWidget *widget, GdkEventButton *event, gpointer data)
 	switch (event->button) {
 		case 1:
 		{
-			viewed_friends (dc);
-			
-			break;
-		}
-		case 2:
-		{
-			
+			view_friends (dc);
 			break;
 		}
+		case 2: break;
 		case 3:
 		{
 			gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, dc, 
-				event->button, event->time);
-			
+					event->button, event->time);
 			break;
 		}
 	}
@@ -179,139 +171,96 @@ clicked (GtkWidget *widget, GdkEventButton *event, gpointer data)
 	return;
 }
 
-void
-tray_hide_entry (DrivelClient *dc)
-{
-	gboolean active;
-	
-	/* keep the "Show Entry" menu item in sync */
-	active = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (show_entry));
-	if (active)
-	{
-		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (show_entry), FALSE);
-		return;
-	}
-	
-	journal_window_state_save (dc);
-	
-	gtk_widget_hide (dc->journal_window);
-	gtk_widget_hide (dc->current_window);
-	
-	return;
-}
+/* Build the tray widget and associated image */
 
-void
-tray_show_entry (DrivelClient *dc)
-{
-	GdkWindowState window_state;
-	gboolean active;
-	
-	/* keep the "Show Entry" menu item in sync */
-	active = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (show_entry));
-	if (!active)
-	{
-		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (show_entry), TRUE);
-		return;
-	}
-	
-	window_state = gdk_window_get_state (dc->current_window->window);
-	if (window_state & GDK_WINDOW_STATE_ICONIFIED)
-		gtk_window_deiconify (GTK_WINDOW (dc->current_window));
-	
-	journal_window_state_restore (dc);
-	
-	return;
-}
-
-void
-tray_icon_update (TrayStatus status)
-{
-	GdkPixbuf *pixbuf;
-	
-	switch (status)
-	{
-		case TRAY_NORMAL:
-		{
-			pixbuf = gtk_image_get_pixbuf (GTK_IMAGE (icon));
-			if (pixbuf)
-				g_object_unref (G_OBJECT (pixbuf));
-			
-			pixbuf = gdk_pixbuf_new_from_file (DATADIR G_DIR_SEPARATOR_S "pixmaps" 
-				G_DIR_SEPARATOR_S "drivel" G_DIR_SEPARATOR_S 
-				"livejournal_tray_normal.png", NULL);
-			
-			gtk_image_set_from_pixbuf (GTK_IMAGE (icon), pixbuf);
-			
-			break;
-		}
-		case TRAY_UPDATED_FRIENDS:
-		{
-			pixbuf = gtk_image_get_pixbuf (GTK_IMAGE (icon));
-			if (pixbuf)
-				g_object_unref (G_OBJECT (pixbuf));
-			
-			pixbuf = gdk_pixbuf_new_from_file (DATADIR G_DIR_SEPARATOR_S "pixmaps" 
-				G_DIR_SEPARATOR_S "drivel" G_DIR_SEPARATOR_S 
-				"livejournal_tray_updated.png", NULL);
-			
-			gtk_image_set_from_pixbuf (GTK_IMAGE (icon), pixbuf);
-			
-			break;
-		}
-	}
-	
-	return;
-}
- 
-void
+static void
 tray_create (DrivelClient *dc)
 {
-	GtkWidget *box;
+	GtkWidget *box, *icon;
+	GdkPixbuf *pixbuf;
 	
 	if (tray_icon)
 		return;
 	
-	if (!menu)
-		create_menu (dc);
+	create_menu (dc);
 	
 	tray_icon = egg_tray_icon_new ("Drivel");
 	box = gtk_event_box_new ();
 	icon = gtk_image_new ();
-	 
+	pixbuf = gdk_pixbuf_new_from_file (DATADIR G_DIR_SEPARATOR_S "pixmaps" 
+			G_DIR_SEPARATOR_S "drivel" G_DIR_SEPARATOR_S 
+			"tray_livejournal.png", NULL);
+	gtk_image_set_from_pixbuf (GTK_IMAGE (icon), pixbuf);
+	
 	gtk_container_add (GTK_CONTAINER (box), icon);
 	gtk_container_add (GTK_CONTAINER (tray_icon), box);
-	gtk_widget_show_all (GTK_WIDGET (tray_icon));
+	gtk_widget_show_all (GTK_WIDGET (box));
+	gtk_widget_hide (GTK_WIDGET (tray_icon)); /* don't display the icon yet */
 	
 	g_signal_connect (G_OBJECT (box), "button-press-event", 
 		G_CALLBACK (clicked), dc);
 	
-	tray_icon_update (TRAY_NORMAL);
-	
-	dc->id.loop_checkfriends_id = g_timeout_add (1000 * CHECKFRIENDS_INTERVAL,
-			checkfriends, dc);
-	
 	return;
 }
 
-void
-tray_destroy (DrivelClient *dc)
+/* Destroy the tray widget and associated image */
+
+static void
+tray_destroy (void)
 {
-	GdkPixbuf *pixbuf;
-	
 	if (!tray_icon)
 		return;
 	
-	g_source_remove (dc->id.loop_checkfriends_id);
-	
-	pixbuf = gtk_image_get_pixbuf (GTK_IMAGE (icon));
-	if (pixbuf)
-		g_object_unref (G_OBJECT (pixbuf));
-	
-	gtk_widget_destroy (icon);
-	icon = NULL;
-	
 	gtk_widget_destroy (GTK_WIDGET (tray_icon));
 	tray_icon = NULL;
 	
 	return;
 }
+
+/* Turn on the LiveJournal Friends Page check */
+
+void
+tray_turn_on (DrivelClient *dc)
+{
+	tray_create (dc);
+	
+	if (dc->user->api == BLOG_API_LJ)
+		checkid = g_timeout_add (1000 * CHECKFRIENDS_INTERVAL, checkfriends, dc);
+	
+	return;
+}
+
+/* Turn off the LiveJournal Friends Page and remove the tray icon */
+
+void
+tray_turn_off (DrivelClient *dc)
+{
+	if (checkid)
+	{
+		g_source_remove (checkid);
+		checkid = 0;
+	}
+	
+	tray_destroy ();
+	
+	return;
+}
+
+/* Display the tray icon */
+
+void
+tray_display (gboolean visible)
+{
+	if (!tray_icon)
+	{
+		g_warning ("You're calling tray_display() before tray_turn_on().  Bad!");
+		return;
+	}
+	
+	if (visible)
+		gtk_widget_show (GTK_WIDGET (tray_icon));
+	else
+		gtk_widget_hide (GTK_WIDGET (tray_icon));
+	
+	return;
+}
