@@ -187,7 +187,7 @@ load_user_list (const gchar *config_dir)
 
 	cur = xmlDocGetRootElement (doc);
 	
-	if (!cur || strcmp (cur->name, "account_list"))
+	if (!cur || strcmp ((gchar *)cur->name, "account_list"))
 	{
 		g_warning ("User list is not valid");
 		return NULL;
@@ -197,34 +197,34 @@ load_user_list (const gchar *config_dir)
 	child = cur->xmlChildrenNode;
 	while (child)
 	{
-		if (!strcmp (child->name, "user_account"))
+		if (!strcmp ((gchar *)child->name, "user_account"))
 		{
 			du = drivel_user_new ();
 			
 			grandchild = child->xmlChildrenNode;
 			while (grandchild)
 			{
-				if (!strcmp (grandchild->name, "username"))
-					du->username = xmlNodeListGetString (doc, 
+				if (!strcmp ((gchar *)grandchild->name, "username"))
+					du->username = (gchar *)xmlNodeListGetString (doc, 
 							grandchild->xmlChildrenNode, 1);
-				if (!strcmp (grandchild->name, "password"))
-					du->password = xmlNodeListGetString (doc, 
+				if (!strcmp ((gchar *)grandchild->name, "password"))
+					du->password = (gchar *)xmlNodeListGetString (doc, 
 							grandchild->xmlChildrenNode, 1);
-				if (!strcmp (grandchild->name, "api"))
+				if (!strcmp ((gchar *)grandchild->name, "api"))
 				{
-					value = xmlNodeListGetString (doc, 
+					value = (gchar *)xmlNodeListGetString (doc, 
 							grandchild->xmlChildrenNode, 1);
 					du->api = (gint) g_strtod (value, NULL);
 					g_free (value);
 				}
-				if (!strcmp (grandchild->name, "server"))
-					du->server = xmlNodeListGetString (doc, 
+				if (!strcmp ((gchar *)grandchild->name, "server"))
+					du->server = (gchar *)xmlNodeListGetString (doc, 
 							grandchild->xmlChildrenNode, 1);
 				
 				grandchild = grandchild->next;
 			}
 			
-			value = xmlGetProp (child, "save_password");
+			value = (gchar *)xmlGetProp (child, (xmlChar *)"save_password");
 			if (value)
 			{
 				du->save_password = (gint) g_strtod (value, NULL);
@@ -232,7 +232,7 @@ load_user_list (const gchar *config_dir)
 			}
 			else
 				du->save_password = 0;
-			value = xmlGetProp (child, "autologin");
+			value = (gchar *)xmlGetProp (child, (xmlChar *)"autologin");
 			if (value)
 			{
 				du->autologin = (gint) g_strtod (value, NULL);
@@ -240,7 +240,7 @@ load_user_list (const gchar *config_dir)
 			}
 			else
 				du->autologin = 0;
-			value = xmlGetProp (child, "lastuser");
+			value = (gchar *)xmlGetProp (child, (xmlChar *)"lastuser");
 			if (value)
 			{
 				du->lastuser = (gint) g_strtod (value, NULL);
@@ -270,29 +270,29 @@ save_user_list (GSList *list, const gchar *config_dir)
 	gchar *filename, *value;
 	
 	/* set up the document */
-	doc = xmlNewDoc ("1.0");
-	doc->children = xmlNewDocNode (doc, NULL, "account_list", NULL);
+	doc = xmlNewDoc ((xmlChar *)"1.0");
+	doc->children = xmlNewDocNode (doc, NULL, (xmlChar *)"account_list", NULL);
 	cur = xmlDocGetRootElement (doc);
 	
 	/* add the user accounts to the xml document */
 	for (item = list; item; item = item->next)
 	{
 		du = item->data;
-		child = xmlNewChild (cur, NULL, "user_account", NULL);
-		xmlNewTextChild (child, NULL, "username", du->username);
-		xmlNewTextChild (child, NULL, "password", du->password);
+		child = xmlNewChild (cur, NULL, (xmlChar *)"user_account", NULL);
+		xmlNewTextChild (child, NULL, (xmlChar *)"username", (xmlChar *)du->username);
+		xmlNewTextChild (child, NULL, (xmlChar *)"password", (xmlChar *)du->password);
 		value = g_strdup_printf ("%d", du->api);
-		xmlNewTextChild (child, NULL, "api", value);
+		xmlNewTextChild (child, NULL, (xmlChar *)"api", (xmlChar *)value);
 		g_free (value);
-		xmlNewTextChild (child, NULL, "server", du->server);
+		xmlNewTextChild (child, NULL, (xmlChar *)"server", (xmlChar *)du->server);
 		value = g_strdup_printf ("%d", du->save_password);
-		xmlNewProp (child, "save_password", value);
+		xmlNewProp (child, (xmlChar *)"save_password", (xmlChar *)value);
 		g_free (value);
 		value = g_strdup_printf ("%d", du->autologin);
-		xmlNewProp (child, "autologin", value);
+		xmlNewProp (child, (xmlChar *)"autologin", (xmlChar *)value);
 		g_free (value);
 		value = g_strdup_printf ("%d", du->lastuser);
-		xmlNewProp (child, "lastuser", value);
+		xmlNewProp (child, (xmlChar *)"lastuser", (xmlChar *)value);
 		g_free (value);
 	}
 	
@@ -464,15 +464,15 @@ md5_hash (const gchar *text)
 	
 	/* md5-hash the text */
 	md5_init (&state);
-	md5_append (&state, text, strlen (text));
+	md5_append (&state, (guchar *)text, strlen (text));
 	md5_finish (&state, digest);
 
 	/* put the hash in lower-case hex */
 	for (i = 0; i < 16; i++)
-		g_snprintf (md5_text + i * 2, 3, "%02x", digest[i]);
+		g_snprintf ((gchar *)md5_text + i * 2, 3, "%02x", digest[i]);
 	md5_text [16 * 2] = '\0';
 	
-	return md5_text;
+	return (gchar *)md5_text;
 }
 
 void
